@@ -30,8 +30,9 @@ for my $n (1 .. $d->bars) {
     two();
 }
 
-$d->play_with_timidity;
 # $d->write;
+# $d->play_with_timidity;
+$d->play_with_fluidsynth;
 
 sub one {
     $d->note($dura, $cymbal, $d->kick);
